@@ -16,7 +16,6 @@
 #'
 #' @return Input dataset with additional column `new_var`.
 #'
-#' @author Annie Yang
 #'
 #' @family der_gen
 #' @keywords der_gen
@@ -68,7 +67,7 @@
 #'     analysis_date = ASTDTM,
 #'     new_var = LDOSE,
 #'     dose_var = EXDOSE,
-#'     traceability_vars = vars(
+#'     traceability_vars = exprs(
 #'       LDOSEDOM = "EX",
 #'       LDOSESEQ = EXSEQ,
 #'       LDOSEVAR = "EXDOSE"
@@ -78,22 +77,22 @@
 derive_var_last_dose_amt <- function(dataset,
                                      dataset_ex,
                                      filter_ex = NULL,
-                                     by_vars = vars(STUDYID, USUBJID),
-                                     dose_id = vars(),
+                                     by_vars = exprs(STUDYID, USUBJID),
+                                     dose_id = exprs(),
                                      dose_date,
                                      analysis_date,
                                      single_dose_condition = (EXDOSFRQ == "ONCE"),
                                      new_var,
                                      dose_var = EXDOSE,
                                      traceability_vars = NULL) {
-  filter_ex <- assert_filter_cond(enquo(filter_ex), optional = TRUE)
+  filter_ex <- assert_filter_cond(enexpr(filter_ex), optional = TRUE)
   by_vars <- assert_vars(by_vars)
   dose_id <- assert_vars(dose_id)
-  dose_date <- assert_symbol(enquo(dose_date))
-  analysis_date <- assert_symbol(enquo(analysis_date))
-  single_dose_condition <- assert_filter_cond(enquo(single_dose_condition))
-  new_var <- assert_symbol(enquo(new_var))
-  dose_var <- assert_symbol(enquo(dose_var))
+  dose_date <- assert_symbol(enexpr(dose_date))
+  analysis_date <- assert_symbol(enexpr(analysis_date))
+  single_dose_condition <- assert_filter_cond(enexpr(single_dose_condition))
+  new_var <- assert_symbol(enexpr(new_var))
+  dose_var <- assert_symbol(enexpr(dose_var))
 
   derive_vars_last_dose(
     dataset = dataset,
@@ -104,7 +103,7 @@ derive_var_last_dose_amt <- function(dataset,
     dose_date = !!dose_date,
     analysis_date = !!analysis_date,
     single_dose_condition = !!single_dose_condition,
-    new_vars = vars(!!new_var := !!dose_var),
+    new_vars = exprs(!!new_var := !!dose_var),
     traceability_vars = traceability_vars
   )
 }
