@@ -1,4 +1,4 @@
-test_that("default duration, i.e., relative day", {
+test_that("compute_duration Test 1: Default duration, i.e., relative day", {
   expect_equal(
     compute_duration(
       ymd_hms("2020-12-06T15:00:00"),
@@ -8,7 +8,7 @@ test_that("default duration, i.e., relative day", {
   )
 })
 
-test_that("fractional duration", {
+test_that("compute_duration Test 2: Fractional duration", {
   expect_equal(
     compute_duration(
       ymd_hms("2020-12-06T15:00:00"),
@@ -20,7 +20,7 @@ test_that("fractional duration", {
   )
 })
 
-test_that("age in years", {
+test_that("compute_duration Test 3: Age in years", {
   expect_equal(
     compute_duration(
       ymd("1984-09-06"),
@@ -33,7 +33,7 @@ test_that("age in years", {
   )
 })
 
-test_that("age in months", {
+test_that("compute_duration Test 4: Age in months", {
   expect_equal(
     compute_duration(
       ymd("1984-09-06"),
@@ -46,7 +46,7 @@ test_that("age in months", {
   )
 })
 
-test_that("age in weeks", {
+test_that("compute_duration Test 5: Age in weeks", {
   expect_equal(
     compute_duration(
       ymd("2020-02-03"),
@@ -58,3 +58,16 @@ test_that("age in weeks", {
     3
   )
 })
+
+test_that("compute_duration Test 6: Duration in hours", {
+  expect_equal(
+    compute_duration(
+      ymd_hms("2020-12-06T9:00:00"),
+      ymd_hms("2020-12-06T13:30:00"),
+      out_unit = "hours",
+      floor_in = FALSE,
+      add_one = FALSE
+    ),
+    4.5
+  )
+})
