@@ -39,7 +39,7 @@ test_that("derive_var_last_dose_amt Test 1: works as expected", {
     input_ae,
     input_ex,
     filter_ex = (EXDOSE > 0) | (EXDOSE == 0 & EXTRT == "placebo"),
-    by_vars = vars(STUDYID, USUBJID),
+    by_vars = exprs(STUDYID, USUBJID),
     dose_date = EXENDT,
     analysis_date = AESTDT,
     new_var = LDOSE,
@@ -65,13 +65,13 @@ test_that("derive_var_last_dose_amt Test 2: returns traceability vars", {
     input_ae,
     input_ex,
     filter_ex = (EXDOSE > 0) | (EXDOSE == 0 & EXTRT == "placebo"),
-    by_vars = vars(STUDYID, USUBJID),
+    by_vars = exprs(STUDYID, USUBJID),
     dose_date = EXENDT,
     analysis_date = AESTDT,
     new_var = LDOSE,
     dose_var = EXDOSE,
     single_dose_condition = (EXSTDTC == EXENDTC),
-    traceability_vars = dplyr::vars(LDOSEDOM = "EX", LDOSESEQ = EXSEQ, LDOSEVAR = "EXSTDTC")
+    traceability_vars = exprs(LDOSEDOM = "EX", LDOSESEQ = EXSEQ, LDOSEVAR = "EXSTDTC")
   )
 
   expect_dfs_equal(expected_output, res, keys = c("STUDYID", "USUBJID", "AESEQ", "AESTDTC"))
