@@ -1,4 +1,5 @@
-test_that("`target` is set to NA when ` start_date` < `ref_start_date`", {
+## Test 1: `start_date` < `ref_start_date` ----
+test_that("derive_var_ontrtfl Test 1: `start_date` < `ref_start_date`", {
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ADT, ~TRTSDT,
     "TEST01", "PAT01", as.Date("2021-01-01"), as.Date("2021-01-02")
@@ -22,7 +23,8 @@ test_that("`target` is set to NA when ` start_date` < `ref_start_date`", {
   )
 })
 
-test_that("`target` is set to NA when `ref_start_date` is NA", {
+## Test 2: `ref_start_date` is NA ----
+test_that("derive_var_ontrtfl Test 2: `ref_start_date` is NA", {
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ADT, ~TRTSDT,
     "TEST01", "PAT01", as.Date("2021-01-01"), as.Date(NA)
@@ -46,7 +48,8 @@ test_that("`target` is set to NA when `ref_start_date` is NA", {
   )
 })
 
-test_that("`target` is set to `Y` when ` start_date` is NA", {
+## Test 3: `start_date` is NA ----
+test_that("derive_var_ontrtfl Test 3: `start_date` is NA", {
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ADT, ~TRTSDT,
     "TEST01", "PAT01", as.Date(NA), as.Date("2020-01-01"),
@@ -72,8 +75,8 @@ test_that("`target` is set to `Y` when ` start_date` is NA", {
   )
 })
 
-test_that("`target` is set to `Y` when ` start_date` >= `ref_start_date` and
-            `ref_end_date` and `filter_pre_timepoint` are not specified", {
+## Test 4: start_date >= ref_start_date, no ref_end_date and filter_pre_timepoint ----
+test_that("derive_var_ontrtfl Test 4: start_date >= ref_start_date, no ref_end_date and filter_pre_timepoint", { # nolint
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ADT, ~TRTSDT,
     "TEST01", "PAT01", as.Date("2020-01-01"), as.Date("2020-01-01"),
@@ -99,8 +102,8 @@ test_that("`target` is set to `Y` when ` start_date` >= `ref_start_date` and
   )
 })
 
-test_that("`target` is set to 'Y' when `filter_pre_timepoint` is not 'PRE' and
-            ` start_date` = `ref_start_date` and `ref_end_date` is not specified", {
+## Test 5: `filter_pre_timepoint` is specified ----
+test_that("derive_var_ontrtfl Test 5: `filter_pre_timepoint` is specified", {
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ADT, ~TRTSDT, ~TPT,
     "TEST01", "PAT01", as.Date("2020-01-01"), as.Date("2020-01-01"), "PRE",
@@ -127,8 +130,8 @@ test_that("`target` is set to 'Y' when `filter_pre_timepoint` is not 'PRE' and
   )
 })
 
-test_that("`target` is set to `Y` when ` start_date` >= `ref_start_date` and ` start_date` <=
-            `ref_end_date` and no `ref_end_window` is specified, otherwise NA", {
+## Test 6: ref_start_date <= start_date <= ref_end_date, no ref_end_window ----
+test_that("derive_var_ontrtfl Test 6: ref_start_date <= start_date <= ref_end_date, no ref_end_window", { # nolint
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ADT, ~TRTSDT, ~TRTEDT,
     "TEST01", "PAT01", as.Date("2019-12-13"), as.Date("2020-01-01"), as.Date("2020-02-01"),
@@ -161,8 +164,8 @@ test_that("`target` is set to `Y` when ` start_date` >= `ref_start_date` and ` s
   )
 })
 
-test_that("`target` is set to `Y` when ` start_date` >= `ref_start_date` and ` start_date` <=
-            `ref_end_date` + `ref_end_window`", {
+## Test 7: ref_start_date <= start_date <= ref_end_date + ref_end_window ----
+test_that("derive_var_ontrtfl Test 7: ref_start_date <= start_date <= ref_end_date + ref_end_window", { # nolint
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ADT, ~TRTSDT, ~TRTEDT,
     "TEST01", "PAT01", as.Date("2020-02-01"), as.Date("2020-01-01"), as.Date("2020-02-01"),
@@ -192,10 +195,42 @@ test_that("`target` is set to `Y` when ` start_date` >= `ref_start_date` and ` s
   )
 })
 
+## Test 8: considering time for ref_end_date ----
+test_that("derive_var_ontrtfl Test 8: considering time for ref_end_date", {
+  expected_output <- tibble::tribble(
+    ~STUDYID, ~USUBJID, ~ADTM,              ~ONTRTFL,
+    "TEST01", "PAT01",  "2020-02-01T12:00", "Y",
+    "TEST01", "PAT02",  "2020-02-06T10:00", "Y",
+    "TEST01", "PAT03",  "2020-02-06T14:00", NA,
+    "TEST01", "PAT03",  "2020-02-10T13:00", NA
+  ) %>%
+    mutate(
+      ADTM = lubridate::ymd_hm(ADTM),
+      TRTSDTM = lubridate::ymd_hm("2020-01-01T12:00"),
+      TRTEDTM = lubridate::ymd_hm("2020-02-01T12:00")
+    )
 
+  input <- select(expected_output, -ONTRTFL)
 
-test_that("`target` is set to  NA when `end_date`<`ref_start_date`
-          regradless of start_date being NA", {
+  actual_output <- derive_var_ontrtfl(
+    input,
+    new_var = ONTRTFL,
+    start_date = ADTM,
+    ref_start_date = TRTSDTM,
+    ref_end_date = TRTEDTM,
+    ref_end_window = 5,
+    ignore_time_for_ref_end_date = FALSE
+  )
+
+  expect_dfs_equal(
+    expected_output,
+    actual_output,
+    keys = c("STUDYID", "USUBJID", "ADTM")
+  )
+})
+
+## Test 9: end_date < ref_start_date and start_date is NA ----
+test_that("derive_var_ontrtfl Test 9: end_date < ref_start_date and start_date is NA", {
   input <- tibble::tribble(
     ~USUBJID, ~ASTDT, ~TRTSDT, ~TRTEDT, ~AENDT,
     "PAT01", ymd("2019-04-30"), ymd("2020-01-01"), ymd("2020-03-01"), ymd("2019-03-15"),
@@ -224,7 +259,8 @@ test_that("`target` is set to  NA when `end_date`<`ref_start_date`
   )
 })
 
-test_that("`target` is set to  `Y` when `end_date`>`ref_start_date` when `start_date` is missing", {
+## Test 10: end_date > ref_start_date and start_date is NA ----
+test_that("derive_var_ontrtfl Test 10: end_date > ref_start_date and start_date is NA", {
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ASTDT, ~TRTSDT, ~TRTEDT, ~AENDT,
     "TEST01", "PAT01", NA, ymd("2020-01-01"), ymd("2020-03-01"), ymd("2021-03-15"),
@@ -251,8 +287,8 @@ test_that("`target` is set to  `Y` when `end_date`>`ref_start_date` when `start_
   )
 })
 
-test_that("`target` is set to  NA when `end_date` is missing and
-            `start_date` is before `ref_start_date`  a la Roche", {
+## Test 11: end_date is NA and start_date < ref_start_date a la Roche ----
+test_that("derive_var_ontrtfl Test 11: end_date is NA and start_date < ref_start_date a la Roche", {
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ASTDT, ~TRTSDT, ~TRTEDT, ~AENDT,
     "TEST01", "PAT01", ymd("2019-04-30"), ymd("2020-01-01"), ymd("2020-03-01"), NA,
@@ -279,8 +315,8 @@ test_that("`target` is set to  NA when `end_date` is missing and
   )
 })
 
-test_that("`target` is set to  Y when `end_date` is missing and
-            `start_date` is before `ref_start_date`  a la GSK", {
+## Test 12: end_date is NA and start_date < ref_start_date a la GSK ----
+test_that("derive_var_ontrtfl Test 12: end_date is NA and start_date < ref_start_date a la GSK", {
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ASTDT, ~TRTSDT, ~TRTEDT, ~AENDT,
     "TEST01", "PAT01", ymd("2019-04-30"), ymd("2020-01-01"), ymd("2020-03-01"), NA,
@@ -308,8 +344,8 @@ test_that("`target` is set to  Y when `end_date` is missing and
   )
 })
 
-test_that("`target` is set to  Y when `end_date` is missing and
-            `start_date` is before `ref_start_date`  a la GSK", {
+## Test 13: end_date is NA and start_date < ref_start_date a la GSK ----
+test_that("derive_var_ontrtfl Test 13: end_date is NA and start_date < ref_start_date a la GSK", {
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ASTDT, ~TRTSDT, ~TRTEDT, ~AENDT,
     "TEST01", "PAT01", ymd("2019-04-30"), ymd("2020-01-01"), ymd("2020-03-01"), NA,
@@ -337,8 +373,8 @@ test_that("`target` is set to  Y when `end_date` is missing and
   )
 })
 
-test_that("`target` is set to Y when `start_date` is before `ref_start_date` and
-            `end_date` is before `ref_end_date` for Period 01", {
+## Test 14: start_date < ref_start_date and end_date < ref_end_date for Period 01 ----
+test_that("derive_var_ontrtfl Test 14: start_date < ref_start_date and end_date < ref_end_date for Period 01", { # nolint
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~ASTDT, ~AP01SDT, ~AP01EDT, ~AENDT,
     "TEST01", "PAT01", ymd("2019-04-30"), ymd("2020-01-01"), ymd("2020-03-01"), ymd("2020-03-15")
