@@ -2,8 +2,8 @@
 test_that("all templates are listed", {
   expect_equal(
     unclass(list_all_templates()),
-    c("ADAE", "ADCM", "ADEG", "ADEX", "ADLB", "ADMH", "ADPP", "ADSL", "ADVS"),
-    check.attributes = FALSE
+    c("ADAE", "ADCM", "ADEG", "ADEX", "ADLB", "ADLBHY", "ADMH", "ADPC", "ADPP", "ADSL", "ADVS"),
+    ignore_attr = TRUE
   )
 })
 
@@ -20,8 +20,8 @@ test_that("Error Message is returned if package is not installed", {
 # use_ad_template ----
 test_that("package templates can be used", {
   dir <- tempdir()
-  file <- file.path(dir, "advs.R")
-  use_ad_template("advs", save_path = file, open = FALSE)
+  suppressMessages(file <- file.path(dir, "advs.R"))
+  suppressMessages(use_ad_template("advs", save_path = file, open = FALSE))
 
   expect_true(file.exists(file))
   expect_identical(
@@ -33,20 +33,20 @@ test_that("package templates can be used", {
 
 test_that("Error Message is returned if no ADaM template is available", {
   dir <- tempdir()
-  file <- file.path(dir, "adxx.R")
+  suppressMessages(file <- file.path(dir, "adxx.R"))
   expect_error(
-    use_ad_template("adxx", save_path = file, open = FALSE),
+    suppressMessages(use_ad_template("adxx", save_path = file, open = FALSE)),
     "No template for 'ADXX' available."
   )
 })
 
 test_that("Error Message is returned if ADaM template file already exists", {
   dir <- tempdir()
-  file <- file.path(dir, "adsl.R")
-  use_ad_template("adsl", save_path = file, open = FALSE)
+  suppressMessages(file <- file.path(dir, "adsl.R"))
+  suppressMessages(use_ad_template("adsl", save_path = file, open = FALSE))
 
   expect_error(
-    use_ad_template("adsl", save_path = file, open = FALSE)
+    suppressMessages(use_ad_template("adsl", save_path = file, open = FALSE))
   )
   file.remove(file)
 })
